      * ---------------------------------------------------------------
      * Module.: XVIDAT_PR            Project.....:
      * Author.: A. Campin            Date written: 01/02/2007
      * Purpose: Convert iSeries type dates (Integer, Decimal, Character Fields)
      *            into true data type. Service program implements SQL UDF.
      *          Service program prototype.
      * ---------------------------------------------------------------
      * Revision history:
      *  Project # Pgmr        Date   Desc
      *
      * End Revision History
      * ---------------------------------------------------------------
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Integer_Default
      *   This function is receives an iSeries date in an integer format
      *     assuming a default format.
      *      Input      - iSeries Date in Integer.
      *                   In Data Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Integer_Default...
     d                 pr
     d   PR_InIntegerValue...
     d                                     Like(StdInt)
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Character_Default
      *   This function is receives an iSeries date in an character format
      *     assuming a default format.
      *   Note that this format can include editing characters like - or /.
      *     They are just stripped out.
      *      Input      - iSeries Date in Varying Character.
      *                   In Data Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Character_Default...
     d                 pr
     d   PR_InCharacterValue...
     d                               10a   Varying
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Date_Default
      *   This function is receives an iSeries date data type and just returns
      *     the date in deault format.
      *      Input      - iSeries Date Data Type.
      *                   In Data Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Date_Default...
     d                 pr
     d   PR_InDateValue...
     d                                     Like(StdDat)
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Packed_Default
      *   This function is receives an iSeries date in an packed format
      *     assuming a default format.
      *      Input      - iSeries Date in Packed Format.
      *                   In Data Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Packed_Default...
     d                 pr
     d   PR_InPackedValue...
     d                                8p 0
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Integer
      *   This function is receives an iSeries date in an integer format
      *     and a date format.
      *      Input      - iSeries Date in Integer.
      *                   Date Format
      *                   In Data Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Integer...
     d                 pr
     d   PR_InIntegerValue...
     d                                     Like(StdInt)
     d   PR_InDateFormat...
     d                               10a   Varying
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_InFormatNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Character
      *   This function is receives an iSeries date in an character format and
      *     a date format.
      *   Note that this format can include editing characters like - or /.
      *     They are just stripped out.
      *      Input      - iSeries Date in Varying Character.
      *                   Date Format
      *                   In Data Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Character...
     d                 pr
     d   PR_InCharacterValue...
     d                               10a   Varying
     d   PR_InDateFormat...
     d                               10a   Varying
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_InFormatNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Date
      *   This function is receives an iSeries date data type and a date format
      *     In this case, format is ignored and the date is just returned.
      *      Input      - iSeries Date Data Type.
      *                   Date Format
      *                   In Data Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Date...
     d                 pr
     d   PR_InDateValue...
     d                                     Like(StdDat)
     d   PR_InDateFormat...
     d                               10a   Varying
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_InFormatNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_Packed
      *   This function is receives an iSeries date in packed 8,0 format and a date format
      *     This function does almost all the work and is called by all the other functions.
      *     Value is converted to date data type and returned.
      *      Input      - Packed 8,0 date field.
      *                   Date Format
      *                   In Data Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Date.
      *                   Return Date Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      *      Output     - None
      *      Returns    - Date in CCYY-MM-DD format
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_Packed...
     d                 pr
     d   PR_InPackedValue...
     d                                8p 0
     d   PR_InDateFormat...
     d                               10a   Varying
     d   PR_OutDate...
     d                                     Like(StdDat)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_InFormatNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_ConvertToIseriesDefault
      *   This function is receives a date data type and assuming a
      *     default format.
      *      Input      - Date Data Type.
      *                   In Date Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Integer in format requested.
      *                   Return Integer Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_ConvertToIseriesDefault...
     d                 pr
     d   PR_InDate...
     d                                     Like(StdDat)
     d   PR_OutIntegerDate...
     d                                     Like(StdInt)
     d   PR_InDateNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_ConvertToIseries
      *   This function is receive a date data type and converts to integer value based on
      *     format requested.
      *      Input      - Date Data Type.
      *                   Date Format
      *                   In Date Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Integer
      *                   Return Integer Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      *      Output     - None
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     d IDAT_ConvertToIseries...
     d                 pr
     d   PR_InDate...
     d                                     Like(StdDat)
     d   PR_InDateFormat...
     d                               10a   Varying
     d   PR_OutInteger...
     d                                     Like(StdInt)
     d   PR_InDataNull...
     d                                     Like(StdIntSml)
     d   PR_InFormatNull...
     d                                     Like(StdIntSml)
     d   PR_OutNull...
     d                                     Like(StdIntSml)
     d   PR_OutSQLState...
     d                                     Like(StdSQLState)
     d   PR_InFunctionName...
     d                              139a   Varying
     d   PR_InSpecificName...
     d                              128a   Varying
     d   PR_OutDiagnosticMessage...
     d                               70a   Varying
